<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 * @return array An array of default values
 */

function top_travel_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$top_travel_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#000',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#ff6633',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		'home_layout'					=> 'default-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',

		//body typography
		'body_font_family'			=> 'Muli',
		'body_font_weight'			=> 300,
		'body_font_size'			=> 16,
		'body_font_style'			=> 'normal',
		'body_text_transform'		=> 'none',

		//h1 typography
		'heading_h1_font_family'		=> 'Raleway',
		'heading_h1_font_weight'		=> 300,
		'heading_h1_text_transform'		=> 'none',
		'heading_h1_font_style'			=> 'normal',

		//h2 typography
		'heading_h2_font_family'		=> 'Raleway',
		'heading_h2_font_weight'		=> 700,
		'heading_h2_text_transform'		=> 'none',
		'heading_h2_font_style'			=> 'normal',

		//h3 typography
		'heading_h3_font_family'		=> 'Raleway',
		'heading_h3_font_weight'		=> 700,
		'heading_h3_text_transform'		=> 'none',
		'heading_h3_font_style'			=> 'normal',

		//h4 typography
		'heading_h4_font_family'		=> 'Raleway',
		'heading_h4_font_weight'		=> 700,
		'heading_h4_text_transform'		=> 'none',
		'heading_h4_font_style'			=> 'normal',

		//h5 typography
		'heading_h5_font_family'		=> 'Raleway',
		'heading_h5_font_weight'		=> 700,
		'heading_h5_text_transform'		=> 'none',
		'heading_h5_font_style'			=> 'normal',

		//h6 typography
		'heading_h6_font_family'		=> 'Raleway',
		'heading_h6_font_weight'		=> 700,
		'heading_h6_text_transform'		=> 'none',
		'heading_h6_font_style'			=> 'normal',

		//p typography
		'heading_p_font_family'			=> 'Muli',
		'heading_p_font_weight'			=> 400,
		'heading_p_text_transform'		=> 'none',
		'heading_p_font_style'			=> 'normal',

		//button
		'button_background_color'		=> '#e5f8fc',
		'button_text_color'		=> '#00afe9',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'social_nav_enable'				=> true,
		'search_icon'					=> true,


		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'top-travel-pro' ), '[the-year]', '[site-link]' ),
		'powered_by_text'           	=> esc_html__( 'All Rights Reserved | ', 'top-travel-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'top-travel-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'slider,about,service,popular_destination,package,testimonial,team,trending,recent,latest_products,popular_products,collection,recent_products,featured_products,trending_product,gallery,counter,popular_posts,content_wrapper,latest_posts,subscription',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'top-travel-pro' ),
		'blog_page_button' 				=> esc_html__( 'READ MORE', 'top-travel-pro' ),
		'single_post_hide_banner'		=> false,
		'hide_date' 					=> false,
		'hide_category'					=> false,
		'hide_author'					=> false,
		'hide_banner'					=> false,		
		'blog_column'					=> 'col-2',
		'blog_layout_design'			=> '',


		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// Top bar
		'top_section_enable'			=> true,
		'top_contact_info'					=> __( 'Any Questions? Call Us: <a href="#">1-223-355-2214</a>', 'top-travel-pro' ),

		// Slider
		'slider_section_enable'		=> true,
		'slider_autoplay'			=> false,
		'slider_arrow'				=> true,
		'slider_content_type'		=> 'category',
		'slider_count'				=> 3,
		'slider_btn_label'			=> esc_html__( 'Discover More', 'top-travel-pro' ),
		'slider_video_label'		=> esc_html__( 'Watch the video', 'top-travel-pro' ),

		// popular destination
		'popular_destination_section_enable'	=> true,
		'popular_destination_content_type'		=> 'category',
		'popular_destination_count'				=> 3,
		'popular_destination_btn_title'			=> esc_html__( 'Book Now', 'top-travel-pro' ),


		// about
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_title'					=> esc_html__( 'Go places you&#39;ve dreamed of', 'top-travel-pro' ),
		'about_sub_title'				=> esc_html__( 'About Us', 'top-travel-pro' ),
		'about_description'				=> esc_html__( 'Between the many mouths to feed, entry to myriad attractions and school holiday price hikes, traveling with kids can quickly add up. Follow these top tips to make your hard-earned cash go further as you and your brood explore the world...', 'top-travel-pro' ),
		'about_btn_title'				=> esc_html__( 'Explore More', 'top-travel-pro' ),
		'about_bg_image'                => '',



		// package
		'package_section_enable'		=> true,
		'package_content_type'			=> 'category',
		'package_title'					=> esc_html__( 'Recommended Packages', 'top-travel-pro' ),
		'package_sub_title'				=> esc_html__( 'Recommended', 'top-travel-pro' ),
		'package_btn_title'				=> esc_html__( 'Book Now', 'top-travel-pro' ),
		'package_bg_image'				=> '',

		
		// service
		'service_section_enable'		=> true,
		'service_section_icon_enable'	=> true,
		'service_content_type'			=> 'category',
		'service_count'					=> 3,
		'service_sub_title'				=> esc_html('Our Service', 'top-travel-pro'),
		'service_title'					=> esc_html('Feel Our Hospitality', 'top-travel-pro'),
		'service_btn_title'				=> esc_html('More Services', 'top-travel-pro'),
		
		// team
		'team_section_enable'		=> true,
		'team_section_icon_enable'	=> true,
		'team_content_type'			=> 'category',
		'team_count'				=> 3,
		'team_sub_title'			=> esc_html('Our team', 'top-travel-pro'),
		'team_title'				=> esc_html('Meet our professional team', 'top-travel-pro'),
		'team_column'				=> '3',

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_auto_play'			=> false,
		'testimonial_content_type'		=> 'category',
		'testimonial_count'				=> 4,
		'testimonial_section_title'		=> esc_html__( 'What Our Clients Says', 'top-travel-pro' ),
		'testimonial_section_sub_title'	=> esc_html__( 'DISOVER US MORE', 'top-travel-pro' ),

		'counter_section_enable'		=> true,

		// subscription
		'subscription_section_enable'	=> true,
		'subscription_sub_title'		=> esc_html__( 'Keep in touch', 'top-travel-pro' ),
		'subscription_title'			=> esc_html__( 'Travel with us!', 'top-travel-pro' ),
		'subscription_btn_title'		=> esc_html__( 'Subscribe Now', 'top-travel-pro' ),

		// trending
		'trending_section_enable'		=> true,
		'trending_content_type'			=> 'category',
		'trending_count'				=> 3,
		'trending_title'				=> esc_html__( 'Most Trending', 'top-travel-pro' ),
		'trending_subtitle'				=> esc_html__( 'POSTS', 'top-travel-pro' ),


		// recent
		'recent_section_enable'			=> true,
		'recent_content_type'			=> 'category',
		'recent_count'					=> 3,
		'recent_title'					=> esc_html__( 'Most Recent', 'top-travel-pro' ),
		'recent_subtitle'				=> esc_html__( 'POSTS', 'top-travel-pro' ),
		'recent_button'					=> esc_html__( 'Keep Reading', 'top-travel-pro' ),

		// popular Posts
		'popular_posts_section_enable'		=> true,
		'popular_posts_count'				=> 5,
		'popular_posts_content_type'		=> 'category',

		// featured
		'featured_section_enable'		=> true,
		'featured_content_type'			=> 'category',
		'featured_count'				=> 4,
		'featured_title'				=> esc_html__( 'DO NOT MISS', 'top-travel-pro' ),

		// most_viewed
		'most_viewed_section_enable'	=> true,
		'most_viewed_content_type'		=> 'category',
		'most_viewed_count'				=> 2,
		'most_viewed_title'				=> esc_html__( 'HOUSE DESIGN', 'top-travel-pro' ),

		// single_column
		'single_column_section_enable'	=> true,
		'single_column_content_type'	=> 'category',
		'single_column_count'			=> 3,
		'single_column_title'			=> esc_html__( 'RECENT POSTS', 'top-travel-pro' ),

		// latest_posts
		'latest_posts_section_enable'	=> true,
		'latest_posts_content_type'		=> 'category',
		'latest_posts_count'			=> 3,
		'latest_posts_title'			=> esc_html__( 'LATEST ARTICLES', 'top-travel-pro' ),

		// latest products
		'latest_products_section_enable'	=> false,
		'latest_products_count'				=> 2,
		'latest_products_content_type'		=> 'product-category',

		//popular products
		'popular_products_section_enable'		=> false,
		'popular_products_content_type'			=> 'product-category',
		'popular_products_count'				=> 4,
		'popular_products_title'				=> esc_html__( 'Shopping Every Day', 'top-travel-pro' ),
		'popular_products_sub_title'			=> esc_html__( 'Autem neglegentur in duo, ex aperiam fabulas mei, exerci menandri explicari ut mei. Eam cibo et.', 'top-travel-pro' ),

		//popular collection
		'collection_section_enable'		=> false,
		'collection_title'				=> esc_html__( 'Spring Collections', 'top-travel-pro' ),
		'collection_subtitle'			=> esc_html__( 'Discover our latest products', 'top-travel-pro' ),

		//recent products
		'recent_products_section_enable'		=> false,
		'recent_products_content_type'			=> 'product-category',
		'recent_products_count'				=> 4,
		'recent_products_title'				=> esc_html__( 'Recent Products', 'top-travel-pro' ),
		'recent_products_sub_title'			=> esc_html__( 'Autem neglegentur in duo, ex aperiam fabulas mei, exerci menandri explicari ut mei. Eam cibo et.', 'top-travel-pro' ),

		//featured section
		'featured_products_section_enable'		=> false,

		//trending_product 
		'trending_product_section_enable'				=> false,
		'trending_product_count'						=> 3,

		// gallery
		'gallery_section_enable'		=> true,
		'gallery_content_type'			=> 'category',
		'gallery_count'					=> 3,
		'gallery_title'					=> esc_html__( 'College Events', 'top-travel-pro' ),
		'gallery_subtitle'				=> esc_html__( 'GALLERY', 'top-travel-pro' ),

	);

	$output = apply_filters( 'top_travel_pro_default_theme_options', $top_travel_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}