<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'top_travel_pro_about_section', array(
	'title'             => esc_html__( 'About Us','top-travel-pro' ),
	'description'       => esc_html__( 'About Us Section options.', 'top-travel-pro' ),
	'panel'             => 'top_travel_pro_front_page_panel',
	'active_callback'	=> 'top_travel_pro_is_about_design_enable',
) );

// About content enable control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'top_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Top_Travel_Pro_Switch_Control( $wp_customize, 'top_travel_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_about_section',
	'on_off_label' 		=> top_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[about_section_enable]', array(
		'selector'            => '#about-us .wrapper',
		'settings'            => 'top_travel_pro_theme_options[about_section_enable]',
    ) );
}

$wp_customize->add_setting( 'top_travel_pro_theme_options[about_bg_image]', array(
	'sanitize_callback' => 'top_travel_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'top_travel_pro_theme_options[about_bg_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'top-travel-pro' ),
		'section'     		=> 'top_travel_pro_about_section',
		'active_callback'	=> 'top_travel_pro_is_about_section_enable',
) ) );

// About content type control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'top_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'top_travel_pro_is_about_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'top-travel-pro' ),
		'post' 		=> esc_html__( 'Post', 'top-travel-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'top-travel-pro' ),
	),
) );

if( in_array( $options['home_layout'], array( 'default-design', 'second-design', 'fourth-design' , 'seventh-design', 'eighth-design', 'ninth-design', 'tenth-design' ) ) ):

// about sub title setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[about_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[about_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_about_section',
	'active_callback' 	=> 'top_travel_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[about_sub_title]', array(
		'selector'            => '#about-us p.section-subtitle',
		'settings'            => 'top_travel_pro_theme_options[about_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_about_sub_title_partial',
    ) );
}

endif;

// about pages drop down chooser control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'top_travel_pro_sanitize_page',
) );

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[about_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_about_section',
	'choices'			=> top_travel_pro_page_choices(),
	'active_callback'	=> 'top_travel_pro_is_about_section_content_page_enable',
) ) );

// about posts drop down chooser control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[about_content_post]', array(
	'sanitize_callback' => 'top_travel_pro_sanitize_page',
) );

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[about_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_about_section',
	'choices'			=> top_travel_pro_post_choices(),
	'active_callback'	=> 'top_travel_pro_is_about_section_content_post_enable',
) ) );

// about title setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[about_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[about_title]', array(
	'label'           	=> esc_html__( 'Title', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_about_section',
	'active_callback' 	=> 'top_travel_pro_is_about_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[about_title]', array(
		'selector'            => '#about-us h2.section-title',
		'settings'            => 'top_travel_pro_theme_options[about_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_about_title_partial',
    ) );
}

// about description setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[about_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['about_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[about_description]', array(
	'label'           	=> esc_html__( 'Description', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_about_section',
	'active_callback' 	=> 'top_travel_pro_is_about_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[about_description]', array(
		'selector'            => '#about-us .wrapper .section-content p',
		'settings'            => 'top_travel_pro_theme_options[about_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_about_description_partial',
    ) );
}

// about btn title setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[about_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[about_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_about_section',
	'active_callback' 	=> 'top_travel_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[about_btn_title]', array(
		'selector'            => '#about-us .wrapper .read-more a',
		'settings'            => 'top_travel_pro_theme_options[about_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_about_btn_title_partial',
    ) );
}

// about btn link setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[about_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[about_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_about_section',
	'active_callback' 	=> 'top_travel_pro_is_about_section_content_custom_enable',
	'type'				=> 'url',
) );

// about image setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[about_image]', array(
	'sanitize_callback' => 'top_travel_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'top_travel_pro_theme_options[about_image]',
		array(
		'label'       		=> esc_html__( 'About Image', 'top-travel-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'top-travel-pro' ), 650, 700 ),
		'section'     		=> 'top_travel_pro_about_section',
		'active_callback'	=> 'top_travel_pro_is_about_section_content_custom_enable',
) ) );


/*color options*/

// Section sub title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[about_subtitle_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[about_subtitle_color]', array(
	'label'             => esc_html__( 'Sub Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_about_section',
	'active_callback' 	=> 'top_travel_pro_is_about_section_enable',
	) ) );


// About title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[about_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[about_title_color]', array(
	'label'             => esc_html__( 'About Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_about_section',
	'active_callback' 	=> 'top_travel_pro_is_about_section_enable',
	) ) );

// About title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[about_hover_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[about_hover_title_color]', array(
	'label'             => esc_html__( 'About Hover Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_about_section',
	'active_callback' 	=> 'top_travel_pro_is_about_section_enable',
	) ) );

// About description color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[about_description_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[about_description_color]', array(
	'label'             => esc_html__( 'About Description Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_about_section',
	'active_callback' 	=> 'top_travel_pro_is_about_section_enable',
	) ) );
if( $options['home_layout'] !== 'fourth-design' ):
// Header title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[about_button_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[about_button_color]', array(
	'label'             => esc_html__( 'Button Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_about_section',
	'active_callback' 	=> 'top_travel_pro_is_about_section_enable',
	) ) );

// Header title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[about_button_hover_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[about_button_hover_color]', array(
	'label'             => esc_html__( 'Button Hover Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_about_section',
	'active_callback' 	=> 'top_travel_pro_is_about_section_enable',
	) ) );
endif;

// Button title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[about_btn_text_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[about_btn_text_color]', array(
	'label'             => esc_html__( 'Button Text Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_about_section',
	'active_callback' 	=> 'top_travel_pro_is_about_section_enable',
	) ) );

