<?php
/**
 * Featured Posts Section options
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */

// Add Featured section
$wp_customize->add_section( 'top_travel_pro_featured_section', array(
	'title'             => esc_html__( 'Featured Posts','top-travel-pro' ),
	'description'       => esc_html__( 'Featured Section options.', 'top-travel-pro' ),
	'panel'             => 'top_travel_pro_front_page_panel',	
	'active_callback' 	=> 'top_travel_pro_is_featured_design_enable',
) );

// Featured content enable control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[featured_section_enable]', array(
	'default'			=> 	$options['featured_section_enable'],
	'sanitize_callback' => 'top_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Top_Travel_Pro_Switch_Control( $wp_customize, 'top_travel_pro_theme_options[featured_section_enable]', array(
	'label'             => esc_html__( 'Featured Section Enable', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_featured_section',
	'on_off_label' 		=> top_travel_pro_switch_options(),
) ) );

// Featured btn label setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[featured_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['featured_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[featured_title]', array(
	'label'           	=> esc_html__( 'Featured Title', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_featured_section',
	'active_callback' 	=> 'top_travel_pro_is_featured_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[featured_title]', array(
		'selector'            => '#magazine-featured-posts h2.section-title',
		'settings'            => 'top_travel_pro_theme_options[featured_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_featured_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[featured_count]', array(
	'default'          	=> $options['featured_count'],
	'sanitize_callback' => 'top_travel_pro_sanitize_number_range',
	'validate_callback' => 'top_travel_pro_validate_featured_count',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[featured_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'top-travel-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_featured_section',
	'active_callback'   => 'top_travel_pro_is_featured_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Featured content type control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[featured_content_type]', array(
	'default'          	=> $options['featured_content_type'],
	'sanitize_callback' => 'top_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[featured_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_featured_section',
	'type'				=> 'select',
	'active_callback' 	=> 'top_travel_pro_is_featured_section_enable',
	'choices'			=> array(
		'page'      => esc_html__( 'Page', 'top-travel-pro' ),
		'post'      => esc_html__( 'Post', 'top-travel-pro' ),
		'category'  => esc_html__( 'Category', 'top-travel-pro' ),
		),
) );

for ( $i = 1; $i <= $options['featured_count']; $i++ ) :
	// featured pages drop down chooser control and setting
	$wp_customize->add_setting( 'top_travel_pro_theme_options[featured_content_page_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[featured_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_featured_section',
		'choices'			=> top_travel_pro_page_choices(),
		'active_callback'	=> 'top_travel_pro_is_featured_section_content_page_enable',
	) ) );

	// featured posts drop down chooser control and setting
	$wp_customize->add_setting( 'top_travel_pro_theme_options[featured_content_post_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[featured_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_featured_section',
		'choices'			=> top_travel_pro_post_choices(),
		'active_callback'	=> 'top_travel_pro_is_featured_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[featured_content_category]', array(
	'sanitize_callback' => 'top_travel_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'top_travel_pro_theme_options[featured_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'top-travel-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_featured_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'top_travel_pro_is_featured_section_content_category_enable'
) ) );

