<?php
/**
 * Gallery Section options
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */

// Add Gallery section
$wp_customize->add_section( 'top_travel_pro_gallery_section', array(
	'title'             => esc_html__( 'Gallery Posts','top-travel-pro' ),
	'description'       => esc_html__( 'Gallery Section options.', 'top-travel-pro' ),
	'panel'             => 'top_travel_pro_front_page_panel',
	'active_callback' 	=> 'top_travel_pro_is_gallery_design_enable',
) );

// Gallery content enable control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[gallery_section_enable]', array(
	'default'			=> 	$options['gallery_section_enable'],
	'sanitize_callback' => 'top_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Top_Travel_Pro_Switch_Control( $wp_customize, 'top_travel_pro_theme_options[gallery_section_enable]', array(
	'label'             => esc_html__( 'Gallery Section Enable', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_gallery_section',
	'on_off_label' 		=> top_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[gallery_section_enable]', array(
		'selector'            => '#our-gallery .wrapper',
		'settings'            => 'top_travel_pro_theme_options[gallery_section_enable]',
    ) );
}

// Gallery btn label setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[gallery_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['gallery_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[gallery_title]', array(
	'label'           	=> esc_html__( 'Title', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_gallery_section',
	'active_callback' 	=> 'top_travel_pro_is_gallery_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[gallery_title]', array(
		'selector'            => '#our-gallery h2.section-title',
		'settings'            => 'top_travel_pro_theme_options[gallery_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_gallery_title_partial',
    ) );
}

// Gallery btn label setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[gallery_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['gallery_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[gallery_subtitle]', array(
	'label'           	=> esc_html__( 'Subtitle', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_gallery_section',
	'active_callback' 	=> 'top_travel_pro_is_gallery_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[gallery_subtitle]', array(
		'selector'            => '#our-gallery p.section-subtitle',
		'settings'            => 'top_travel_pro_theme_options[gallery_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_gallery_subtitle_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[gallery_count]', array(
	'default'          	=> $options['gallery_count'],
	'sanitize_callback' => 'top_travel_pro_sanitize_number_range',
	'validate_callback' => 'top_travel_pro_validate_gallery_count',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[gallery_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'top-travel-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_gallery_section',
	'active_callback'   => 'top_travel_pro_is_gallery_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Gallery content type control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[gallery_content_type]', array(
	'default'          	=> $options['gallery_content_type'],
	'sanitize_callback' => 'top_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[gallery_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_gallery_section',
	'type'				=> 'select',
	'active_callback' 	=> 'top_travel_pro_is_gallery_section_enable',
	'choices'			=> array(
		'page'      => esc_html__( 'Page', 'top-travel-pro' ),
		'post'      => esc_html__( 'Post', 'top-travel-pro' ),
		'category'  => esc_html__( 'Category', 'top-travel-pro' ),
		),
) );

for ( $i = 1; $i <= $options['gallery_count']; $i++ ) :
	// gallery pages drop down chooser control and setting
	$wp_customize->add_setting( 'top_travel_pro_theme_options[gallery_content_page_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[gallery_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_gallery_section',
		'choices'			=> top_travel_pro_page_choices(),
		'active_callback'	=> 'top_travel_pro_is_gallery_section_content_page_enable',
	) ) );

	// gallery posts drop down chooser control and setting
	$wp_customize->add_setting( 'top_travel_pro_theme_options[gallery_content_post_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[gallery_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_gallery_section',
		'choices'			=> top_travel_pro_post_choices(),
		'active_callback'	=> 'top_travel_pro_is_gallery_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[gallery_content_category]', array(
	'sanitize_callback' => 'top_travel_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'top_travel_pro_theme_options[gallery_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'top-travel-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_gallery_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'top_travel_pro_is_gallery_section_content_category_enable'
) ) );

/*color options*/

// Section sub title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[gallery_section_subtitle_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[gallery_section_subtitle_color]', array(
	'label'             => esc_html__( 'Section Sub Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_gallery_section',
	'active_callback' 	=> 'top_travel_pro_is_gallery_section_enable',
	) ) );

// Section title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[gallery_section_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[gallery_section_title_color]', array(
	'label'             => esc_html__( 'Section Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_gallery_section',
	'active_callback' 	=> 'top_travel_pro_is_gallery_section_enable',
	) ) );

// Gallery title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[gallery_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[gallery_title_color]', array(
	'label'             => esc_html__( 'Gallery Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_gallery_section',
	'active_callback' 	=> 'top_travel_pro_is_gallery_section_enable',
	) ) );

// Gallery title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[gallery_hover_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[gallery_hover_title_color]', array(
	'label'             => esc_html__( 'Gallery Hover Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_gallery_section',
	'active_callback' 	=> 'top_travel_pro_is_gallery_section_enable',
	) ) );