<?php
/**
 * Package Section options
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */

// Add Package section
$wp_customize->add_section( 'top_travel_pro_package_section', array(
	'title'             => esc_html__( 'Package','top-travel-pro' ),
	'description'       => esc_html__( 'Package Section options.', 'top-travel-pro' ),
	'panel'             => 'top_travel_pro_front_page_panel',
	'active_callback' 	=> 'top_travel_pro_is_package_design_enable',
) );

// Package content enable control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_section_enable]', array(
	'default'			=> 	$options['package_section_enable'],
	'sanitize_callback' => 'top_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Top_Travel_Pro_Switch_Control( $wp_customize, 'top_travel_pro_theme_options[package_section_enable]', array(
	'label'             => esc_html__( 'Package Section Enable', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_package_section',
	'on_off_label' 		=> top_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[package_section_enable]', array(
		'selector'            => '.recommended-hotels-package .recommended-hotels-wrapper',
		'settings'            => 'top_travel_pro_theme_options[package_section_enable]',
    ) );
}

// package title setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['package_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[package_title]', array(
	'label'           	=> esc_html__( 'Title', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_package_section',
	'active_callback' 	=> 'top_travel_pro_is_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[package_title]', array(
		'selector'            => '.recommended-hotels-package h2.recommended-hotels-title',
		'settings'            => 'top_travel_pro_theme_options[package_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_package_title_partial',
    ) );
}

$wp_customize->add_setting( 'top_travel_pro_theme_options[package_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['package_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[package_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_package_section',
	'active_callback' 	=> 'top_travel_pro_is_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[package_sub_title]', array(
		'selector'            => '.recommended-hotels-package p.recommended-hotels-subtitle',
		'settings'            => 'top_travel_pro_theme_options[package_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_package_sub_title_partial',
    ) );
}

$wp_customize->add_setting( 'top_travel_pro_theme_options[package_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['package_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[package_btn_title]', array(
	'label'           	=> esc_html__( 'Btn Title', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_package_section',
	'active_callback' 	=> 'top_travel_pro_is_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[package_btn_title]', array(
		'selector'            => '.recommended-hotels-package .read-more a',
		'settings'            => 'top_travel_pro_theme_options[package_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_package_btn_title_partial',
    ) );
}

$wp_customize->add_setting( 'top_travel_pro_theme_options[package_bg_image]', array(
	'sanitize_callback' => 'top_travel_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'top_travel_pro_theme_options[package_bg_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'top-travel-pro' ),
		'section'     		=> 'top_travel_pro_package_section',
		'active_callback'	=> 'top_travel_pro_is_package_section_enable',
) ) );

// Package content type control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_content_type]', array(
	'default'          	=> $options['package_content_type'],
	'sanitize_callback' => 'top_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[package_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_package_section',
	'type'				=> 'select',
	'active_callback' 	=> 'top_travel_pro_is_package_section_enable',
	'choices'			=> top_travel_pro_package_content_type(),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[package_content_category]', array(
	'sanitize_callback' => 'top_travel_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Category_Control( $wp_customize,'top_travel_pro_theme_options[package_content_category]', array(
	'label'             => esc_html__( 'Select Multiple Category', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_package_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'top_travel_pro_is_package_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[package_content_trip_types]', array(
	'sanitize_callback' => 'top_travel_pro_sanitize_integers',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Category_Control( $wp_customize,'top_travel_pro_theme_options[package_content_trip_types]', array(
	'label'             => esc_html__( 'Select Multiple Trip Types', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_package_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'top_travel_pro_is_package_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[package_content_activity]', array(
	'sanitize_callback' => 'top_travel_pro_sanitize_integers',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Category_Control( $wp_customize,'top_travel_pro_theme_options[package_content_activity]', array(
	'label'             => esc_html__( 'Select Multiple Activities', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_package_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'top_travel_pro_is_package_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[package_content_destination]', array(
	'sanitize_callback' => 'top_travel_pro_sanitize_integers',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Category_Control( $wp_customize,'top_travel_pro_theme_options[package_content_destination]', array(
	'label'             => esc_html__( 'Select Multiple Destination', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_package_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'top_travel_pro_is_package_section_content_destination_enable'
) ) );


/*color options*/

// Section sub title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_section_subtitle_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[package_section_subtitle_color]', array(
	'label'             => esc_html__( 'Section Sub Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_package_section',
	'active_callback' 	=> 'top_travel_pro_is_package_section_enable',
	) ) );

// Section title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_section_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[package_section_title_color]', array(
	'label'             => esc_html__( 'Section Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_package_section',
	'active_callback' 	=> 'top_travel_pro_is_package_section_enable',
	) ) );

// Package title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[package_title_color]', array(
	'label'             => esc_html__( 'Package Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_package_section',
	'active_callback' 	=> 'top_travel_pro_is_package_section_enable',
	) ) );

// Package title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_hover_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[package_hover_title_color]', array(
	'label'             => esc_html__( 'Package Hover Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_package_section',
	'active_callback' 	=> 'top_travel_pro_is_package_section_enable',
	) ) );

// Package description color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_description_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[package_description_color]', array(
	'label'             => esc_html__( 'Package Description Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_package_section',
	'active_callback' 	=> 'top_travel_pro_is_package_section_enable',
	) ) );

// Header title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_button_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[package_button_color]', array(
	'label'             => esc_html__( 'Button Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_package_section',
	'active_callback' 	=> 'top_travel_pro_is_package_section_enable',
	) ) );

// Header title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_button_hover_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[package_button_hover_color]', array(
	'label'             => esc_html__( 'Button Hover Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_package_section',
	'active_callback' 	=> 'top_travel_pro_is_package_section_enable',
	) ) );

// Button title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_btn_text_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[package_btn_text_color]', array(
	'label'             => esc_html__( 'Button Text Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_package_section',
	'active_callback' 	=> 'top_travel_pro_is_package_section_enable',
	) ) );

