<?php
/**
 * Products Collection Section options
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */

// Add collection section
$wp_customize->add_section( 'top_travel_pro_collection_section', array(
	'title'             => esc_html__( 'Products Collection','top-travel-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'top-travel-pro' ),
	'panel'             => 'top_travel_pro_front_page_panel',
	'active_callback'   => 'top_travel_pro_is_collection_design_enable',
) );

// collection content enable control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[collection_section_enable]', array(
	'default'			=> 	$options['collection_section_enable'],
	'sanitize_callback' => 'top_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Top_Travel_Pro_Switch_Control( $wp_customize, 'top_travel_pro_theme_options[collection_section_enable]', array(
	'label'             => esc_html__( 'collection Section Enable', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_collection_section',
	'on_off_label' 		=> top_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[collection_section_enable]', array(
        'selector'            => '#products-collection .wrapper',
        'settings'            => 'top_travel_pro_theme_options[collection_section_enable]',
    ) );
}

// collection title setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[collection_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['collection_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[collection_title]', array(
	'label'           	=> esc_html__( 'Title', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_collection_section',
	'active_callback' 	=> 'top_travel_pro_is_collection_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[collection_title]', array(
        'selector'            => '#products-collection h2.section-title',
        'settings'            => 'top_travel_pro_theme_options[collection_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'top_travel_pro_collection_title_partial',
    ) );
}

// collection subtitle setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[collection_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['collection_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[collection_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_collection_section',
	'active_callback' 	=> 'top_travel_pro_is_collection_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[collection_subtitle]', array(
        'selector'            => '#products-collection p.subtitle',
        'settings'            => 'top_travel_pro_theme_options[collection_subtitle]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'top_travel_pro_collection_subtitle_partial',
    ) );
}


for ( $i = 1; $i <= 4; $i++ ) :

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'top_travel_pro_theme_options[collection_content_collection_category_'.$i.']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'top_travel_pro_theme_options[collection_content_collection_category_'.$i.']', array(
		'label'             => esc_html__( 'Select collection Category ', 'top-travel-pro' ).$i,
		'section'           => 'top_travel_pro_collection_section',
		'taxonomy'			=> 'product_cat',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'top_travel_pro_is_collection_section_enable'
	) ) );

	$wp_customize->add_setting( 'top_travel_pro_theme_options[collection_banner_title_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'top_travel_pro_theme_options[collection_banner_title_'.$i.']', array(
		'label'           	=> esc_html__( 'Banner Title ', 'top-travel-pro' ).$i,
		'section'        	=> 'top_travel_pro_collection_section',
		'active_callback' 	=> 'top_travel_pro_is_collection_section_enable',
		'type'				=> 'text',
	) );

endfor;

/*color options*/

// Section sub title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[collection_section_title_color]', array(
    'sanitize_callback' => 'sanitize_hex_color',
    'transport'         => 'refresh'
    ) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[collection_section_title_color]', array(
    'label'             => esc_html__( 'Section Title Color', 'top-travel-pro' ),
    'section'           => 'top_travel_pro_collection_section',
    'active_callback'   => 'top_travel_pro_is_collection_section_enable',
    ) ) );

// Section title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[collection_section_description_color]', array(
    'sanitize_callback' => 'sanitize_hex_color',
    'transport'         => 'refresh'
    ) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[collection_section_description_color]', array(
    'label'             => esc_html__( 'Section Description Color', 'top-travel-pro' ),
    'section'           => 'top_travel_pro_collection_section',
    'active_callback'   => 'top_travel_pro_is_collection_section_enable',
    ) ) );