<?php
/**
 * Recent Section options
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */

// Add Recent section
$wp_customize->add_section( 'top_travel_pro_recent_section', array(
	'title'             => esc_html__( 'Recent Posts','top-travel-pro' ),
	'description'       => esc_html__( 'Recent Section options.', 'top-travel-pro' ),
	'panel'             => 'top_travel_pro_front_page_panel',
	'active_callback' 	=> 'top_travel_pro_is_recent_design_enable',
) );

// Recent content enable control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[recent_section_enable]', array(
	'default'			=> 	$options['recent_section_enable'],
	'sanitize_callback' => 'top_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Top_Travel_Pro_Switch_Control( $wp_customize, 'top_travel_pro_theme_options[recent_section_enable]', array(
	'label'             => esc_html__( 'Recent Section Enable', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_recent_section',
	'on_off_label' 		=> top_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[recent_section_enable]', array(
		'selector'            => '.recent-section .recent-wrapper',
		'settings'            => 'top_travel_pro_theme_options[recent_section_enable]',
    ) );
}

// Recent btn label setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[recent_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[recent_title]', array(
	'label'           	=> esc_html__( 'Recent Title', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_recent_section',
	'active_callback' 	=> 'top_travel_pro_is_recent_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[recent_title]', array(
		'selector'            => '.recent-section h2.recent-title',
		'settings'            => 'top_travel_pro_theme_options[recent_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_recent_title_partial',
    ) );
}

if ( in_array( $options['home_layout'], array( 'default-design', 'third-design', 'fourth-design', 'tenth-design' ) ) ):

// Recent btn label setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[recent_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[recent_subtitle]', array(
	'label'           	=> esc_html__( 'Subtitle', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_recent_section',
	'active_callback' 	=> 'top_travel_pro_is_recent_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[recent_subtitle]', array(
		'selector'            => '.recent-section p.recent-subtitle',
		'settings'            => 'top_travel_pro_theme_options[recent_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_recent_subtitle_partial',
    ) );
}

$wp_customize->add_setting( 'top_travel_pro_theme_options[recent_bg_image]', array(
	'sanitize_callback' => 'top_travel_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'top_travel_pro_theme_options[recent_bg_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'top-travel-pro' ),
		'section'     		=> 'top_travel_pro_recent_section',
		'active_callback'	=> 'top_travel_pro_is_recent_section_enable',
) ) );

endif;

// Event social icons number control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[recent_count]', array(
	'default'          	=> $options['recent_count'],
	'sanitize_callback' => 'top_travel_pro_sanitize_number_range',
	'validate_callback' => 'top_travel_pro_validate_recent_count',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[recent_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'top-travel-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_recent_section',
	'active_callback'   => 'top_travel_pro_is_recent_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Recent content type control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[recent_content_type]', array(
	'default'          	=> $options['recent_content_type'],
	'sanitize_callback' => 'top_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[recent_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_recent_section',
	'type'				=> 'select',
	'active_callback' 	=> 'top_travel_pro_is_recent_section_enable',
	'choices'			=> array(
		'page'      => esc_html__( 'Page', 'top-travel-pro' ),
		'post'      => esc_html__( 'Post', 'top-travel-pro' ),
		'category'  => esc_html__( 'Category', 'top-travel-pro' ),
		),
) );

for ( $i = 1; $i <= $options['recent_count']; $i++ ) :
	// recent pages drop down chooser control and setting
	$wp_customize->add_setting( 'top_travel_pro_theme_options[recent_content_page_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[recent_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_recent_section',
		'choices'			=> top_travel_pro_page_choices(),
		'active_callback'	=> 'top_travel_pro_is_recent_section_content_page_enable',
	) ) );

	// recent posts drop down chooser control and setting
	$wp_customize->add_setting( 'top_travel_pro_theme_options[recent_content_post_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[recent_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_recent_section',
		'choices'			=> top_travel_pro_post_choices(),
		'active_callback'	=> 'top_travel_pro_is_recent_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[recent_content_category]', array(
	'sanitize_callback' => 'top_travel_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'top_travel_pro_theme_options[recent_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'top-travel-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_recent_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'top_travel_pro_is_recent_section_content_category_enable'
) ) );

if ( $options['home_layout'] == 'third-design' || $options['home_layout'] == 'fourth-design' ):

// Recent btn label setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[recent_button]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_button'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[recent_button]', array(
	'label'           	=> esc_html__( 'Button', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_recent_section',
	'active_callback' 	=> 'top_travel_pro_is_recent_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[recent_button]', array(
		'selector'            => '#recommended-hotels div.hotels-slider div.read-more a.btn',
		'settings'            => 'top_travel_pro_theme_options[recent_button]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_recent_button_partial',
    ) );
}

endif;

if ( $options['home_layout'] == 'fifth-design' ):

$wp_customize->add_setting( 'top_travel_pro_theme_options[ads_image]', array(
	'sanitize_callback' => 'top_travel_pro_sanitize_image'
	) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'top_travel_pro_theme_options[ads_image]',
	array(
		'label'       		=> esc_html__( 'Ads Image', 'top-travel-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'top-travel-pro' ), 728, 90 ),
		'section'     		=> 'top_travel_pro_recent_section',
		'active_callback'	=> 'top_travel_pro_is_recent_section_enable',
		) ) );
	// ads btn link setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[ads_link]', array(
	'sanitize_callback' => 'esc_url_raw',
	) );

$wp_customize->add_control( 'top_travel_pro_theme_options[ads_link]', array(
	'label'           	=> esc_html__( 'Ads Link', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_recent_section',
	'active_callback' 	=> 'top_travel_pro_is_recent_section_enable',
	'type'				=> 'url',
	) );
	
endif;

/*color options*/

if( $options['home_layout'] !== 'fifth-design' ){

// Section sub title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_section_subtitle_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[package_section_subtitle_color]', array(
	'label'             => esc_html__( 'Section Sub Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_recent_section',
	'active_callback' 	=> 'top_travel_pro_is_recent_section_enable',
	) ) );

// Section title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_section_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[package_section_title_color]', array(
	'label'             => esc_html__( 'Section Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_recent_section',
	'active_callback' 	=> 'top_travel_pro_is_recent_section_enable',
	) ) );

// Recent title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[package_title_color]', array(
	'label'             => esc_html__( 'Recent Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_recent_section',
	'active_callback' 	=> 'top_travel_pro_is_recent_section_enable',
	) ) );

// Recent title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_hover_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[package_hover_title_color]', array(
	'label'             => esc_html__( 'Recent Hover Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_recent_section',
	'active_callback' 	=> 'top_travel_pro_is_recent_section_enable',
	) ) );

// Recent description color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_description_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[package_description_color]', array(
	'label'             => esc_html__( 'Recent Description Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_recent_section',
	'active_callback' 	=> 'top_travel_pro_is_recent_section_enable',
	) ) );

// Header title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_button_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[package_button_color]', array(
	'label'             => esc_html__( 'Button Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_recent_section',
	'active_callback' 	=> 'top_travel_pro_is_recent_section_enable',
	) ) );

// Header title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_button_hover_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[package_button_hover_color]', array(
	'label'             => esc_html__( 'Button Hover Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_recent_section',
	'active_callback' 	=> 'top_travel_pro_is_recent_section_enable',
	) ) );

// Button title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_btn_text_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[package_btn_text_color]', array(
	'label'             => esc_html__( 'Button Text Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_recent_section',
	'active_callback' 	=> 'top_travel_pro_is_recent_section_enable',
	) ) );

}
