<?php
/**
 * Subscription Section options
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */

// Add Subscription section
$wp_customize->add_section( 'top_travel_pro_subscription_section', array(
	'title'             => esc_html__( 'Subscription','top-travel-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install Jetpack Plugin and activate subscription module.', 'top-travel-pro' ),
	'panel'             => 'top_travel_pro_front_page_panel',
	'active_callback' 	=> 'top_travel_pro_is_subscription_design_enable',
) );

// Subscription content enable control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[subscription_section_enable]', array(
	'default'			=> 	$options['subscription_section_enable'],
	'sanitize_callback' => 'top_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Top_Travel_Pro_Switch_Control( $wp_customize, 'top_travel_pro_theme_options[subscription_section_enable]', array(
	'label'             => esc_html__( 'Subscription Section Enable', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_subscription_section',
	'on_off_label' 		=> top_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[subscription_section_enable]', array(
		'selector'            => '#subscribe-now .wrapper',
		'settings'            => 'top_travel_pro_theme_options[subscription_section_enable]',
    ) );
}

// subscription description setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[subscription_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[subscription_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_subscription_section',
	'active_callback' 	=> 'top_travel_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[subscription_sub_title]', array(
		'selector'            => '#subscribe-now .section-header p.section-subtitle',
		'settings'            => 'top_travel_pro_theme_options[subscription_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_subscription_sub_title_partial',
    ) );
}

// subscription title setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[subscription_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[subscription_title]', array(
	'label'           	=> esc_html__( 'Title', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_subscription_section',
	'active_callback' 	=> 'top_travel_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[subscription_title]', array(
		'selector'            => '#subscribe-now .section-header h2.section-title',
		'settings'            => 'top_travel_pro_theme_options[subscription_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_subscription_title_partial',
    ) );
}

// subscription btn title setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[subscription_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_btn_title'],
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[subscription_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_subscription_section',
	'active_callback' 	=> 'top_travel_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

/*color options*/

// Subscription sub title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[subscription_subtitle_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[subscription_subtitle_color]', array(
	'label'             => esc_html__( 'Subscription Sub Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_subscription_section',
	'active_callback' 	=> 'top_travel_pro_is_subscription_section_enable',
	) ) );

// Subscription title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[subscription_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[subscription_title_color]', array(
	'label'             => esc_html__( 'Subscription Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_subscription_section',
	'active_callback' 	=> 'top_travel_pro_is_subscription_section_enable',
	) ) );
// Header title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[subscription_button_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[subscription_button_color]', array(
	'label'             => esc_html__( 'Button Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_subscription_section',
	'active_callback' 	=> 'top_travel_pro_is_subscription_section_enable',
	) ) );

// Header title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[subscription_button_hover_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[subscription_button_hover_color]', array(
	'label'             => esc_html__( 'Button Hover Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_subscription_section',
	'active_callback' 	=> 'top_travel_pro_is_subscription_section_enable',
	) ) );

// Button title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[subscription_btn_text_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[subscription_btn_text_color]', array(
	'label'             => esc_html__( 'Button Text Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_subscription_section',
	'active_callback' 	=> 'top_travel_pro_is_subscription_section_enable',
	) ) );