<?php
/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section( 'top_travel_pro_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial','top-travel-pro' ),
	'description'       => esc_html__( 'Testimonial Section options.', 'top-travel-pro' ),
	'panel'             => 'top_travel_pro_front_page_panel',
	'active_callback' 	=> 'top_travel_pro_is_testimonial_design_enable',
) );

// Testimonial content enable control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_section_enable]', array(
	'default'			=> 	$options['testimonial_section_enable'],
	'sanitize_callback' => 'top_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Top_Travel_Pro_Switch_Control( $wp_customize, 'top_travel_pro_theme_options[testimonial_section_enable]', array(
	'label'             => esc_html__( 'Testimonial Section Enable', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_testimonial_section',
	'on_off_label' 		=> top_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[testimonial_section_enable]', array(
		'selector'            => '.testimonial-class .testimonial-class-wrapper',
		'settings'            => 'top_travel_pro_theme_options[testimonial_section_enable]',
    ) );
}

// Testimonial auto play enable control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_auto_play]', array(
	'default'			=> 	$options['testimonial_auto_play'],
	'sanitize_callback' => 'top_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Top_Travel_Pro_Switch_Control( $wp_customize, 'top_travel_pro_theme_options[testimonial_auto_play]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_testimonial_section',
	'on_off_label' 		=> top_travel_pro_switch_options(),
) ) );

$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_section_title]', array(
	'default'          	=> $options['testimonial_section_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[testimonial_section_title]', array(
	'label'             => esc_html__( 'Section Title', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_testimonial_section',
	'type'				=> 'text',
	'active_callback' 	=> 'top_travel_pro_is_testimonial_section_enable',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[testimonial_section_title]', array(
		'selector'            => '.testimonial-class h2.testimonial-class-title',
		'settings'            => 'top_travel_pro_theme_options[testimonial_section_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_testimonial_section_title_partial',
    ) );
}

$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_section_sub_title]', array(
	'default'          	=> $options['testimonial_section_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[testimonial_section_sub_title]', array(
	'label'             => esc_html__( 'Section Sub Title', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_testimonial_section',
	'type'				=> 'text',
	'active_callback' 	=> 'top_travel_pro_is_testimonial_section_enable',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[testimonial_section_sub_title]', array(
		'selector'            => '.testimonial-class p.testimonial-class-subtitle',
		'settings'            => 'top_travel_pro_theme_options[testimonial_section_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_testimonial_section_sub_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_count]', array(
	'default'          	=> $options['testimonial_count'],
	'sanitize_callback' => 'top_travel_pro_sanitize_number_range',
	'validate_callback' => 'top_travel_pro_validate_testimonial_count',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[testimonial_count]', array(
	'label'             => esc_html__( 'Number of Testimonials', 'top-travel-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_testimonial_section',
	'active_callback'   => 'top_travel_pro_is_testimonial_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Testimonial content type control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_content_type]', array(
	'default'          	=> $options['testimonial_content_type'],
	'sanitize_callback' => 'top_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[testimonial_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_testimonial_section',
	'type'				=> 'select',
	'active_callback' 	=> 'top_travel_pro_is_testimonial_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'top-travel-pro' ),
		'post' 		=> esc_html__( 'Post', 'top-travel-pro' ),
		'category' 	=> esc_html__( 'Category', 'top-travel-pro' ),
	),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[testimonial_content_category]', array(
	'sanitize_callback' => 'top_travel_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'top_travel_pro_theme_options[testimonial_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'top-travel-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_testimonial_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'top_travel_pro_is_testimonial_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['testimonial_count']; $i++ ) :
	// testimonial pages drop down chooser control and setting
	$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_testimonial_section',
		'choices'			=> top_travel_pro_page_choices(),
		'active_callback'	=> 'top_travel_pro_is_testimonial_section_content_page_enable',
	) ) );

	// testimonial posts drop down chooser control and setting
	$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_testimonial_section',
		'choices'			=> top_travel_pro_post_choices(),
		'active_callback'	=> 'top_travel_pro_is_testimonial_section_content_post_enable',
	) ) );

	// testimonial title setting and control
	$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'top_travel_pro_theme_options[testimonial_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Title %d', 'top-travel-pro' ), $i ),
		'section'        	=> 'top_travel_pro_testimonial_section',
		'active_callback' 	=> 'top_travel_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'text',
	) );

	// testimonial description setting and control
	$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_description_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'top_travel_pro_theme_options[testimonial_description_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Description %d', 'top-travel-pro' ), $i ),
		'section'        	=> 'top_travel_pro_testimonial_section',
		'active_callback' 	=> 'top_travel_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'textarea',
	) );

	// testimonial image setting and control.
	$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_image_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'top_travel_pro_theme_options[testimonial_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'top-travel-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'top-travel-pro' ), 700, 600 ),
			'section'     		=> 'top_travel_pro_testimonial_section',
			'active_callback'	=> 'top_travel_pro_is_testimonial_section_content_custom_enable',
	) ) );

	// testimonial position setting and control
	$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'top_travel_pro_theme_options[testimonial_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'URL Link %d', 'top-travel-pro' ), $i ),
		'section'        	=> 'top_travel_pro_testimonial_section',
		'active_callback' 	=> 'top_travel_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'url',
	) );

	$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_client_image_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'top_travel_pro_theme_options[testimonial_client_image_' . $i . ']',
			array(
			'label'       		=> esc_html__( 'Client Image ', 'top-travel-pro' ).$i,
			'section'     		=> 'top_travel_pro_testimonial_section',
			'active_callback'	=> 'top_travel_pro_is_testimonial_section_enable',
	) ) );

	$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_client_name_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'top_travel_pro_theme_options[testimonial_client_name_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Client Name %d', 'top-travel-pro' ), $i ),
		'section'        	=> 'top_travel_pro_testimonial_section',
		'active_callback' 	=> 'top_travel_pro_is_testimonial_section_enable',
		'type'				=> 'text',
	) );
	$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_client_position_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'top_travel_pro_theme_options[testimonial_client_position_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Client Position %d', 'top-travel-pro' ), $i ),
		'section'        	=> 'top_travel_pro_testimonial_section',
		'active_callback' 	=> 'top_travel_pro_is_testimonial_section_enable',
		'type'				=> 'text',
	) );


	// testimonial hr setting and control
	$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Customize_Horizontal_Line( $wp_customize, 'top_travel_pro_theme_options[testimonial_hr_'. $i .']',
		array(
			'section'         => 'top_travel_pro_testimonial_section',
			'active_callback' => 'top_travel_pro_is_testimonial_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;

/*color options*/

// Section sub title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_section_subtitle_color]', array(
	'default'           => '#ff6633',
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[testimonial_section_subtitle_color]', array(
	'label'             => esc_html__( 'Section Sub Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_testimonial_section',
	'active_callback' 	=> 'top_travel_pro_is_testimonial_section_enable',
	) ) );

// Section title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_section_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[testimonial_section_title_color]', array(
	'label'             => esc_html__( 'Section Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_testimonial_section',
	'active_callback' 	=> 'top_travel_pro_is_testimonial_section_enable',
	) ) );

// Testimonial title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[testimonial_title_color]', array(
	'label'             => esc_html__( 'Testimonial Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_testimonial_section',
	'active_callback' 	=> 'top_travel_pro_is_testimonial_section_enable',
	) ) );

// Testimonial title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_hover_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[testimonial_hover_title_color]', array(
	'label'             => esc_html__( 'Testimonial Hover Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_testimonial_section',
	'active_callback' 	=> 'top_travel_pro_is_testimonial_section_enable',
	) ) );

// Testimonial description color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_description_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[testimonial_description_color]', array(
	'label'             => esc_html__( 'Testimonial Description Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_testimonial_section',
	'active_callback' 	=> 'top_travel_pro_is_testimonial_section_enable',
	) ) );